test_reporter library

Classes

Test
A single test case. The test's ID is unique in the context of this test run. It's used elsewhere in the protocol to refer to this test without including its full representation.
TestEvent
This is the root class of the protocol. All root-level objects emitted by the JSON reporter will be subclasses of TestEvent. https://github.com/dart-lang/test/blob/master/pkgs/test/doc/json_reporter.md
TestGroup
A group containing test cases. The group's ID is unique in the context of this test run. It's used elsewhere in the protocol to refer to this group without including its full representation.
TestMetadata
Test metadata regarding whether the test was skipped and the reason.
TestReporter
Special reporter class to implement test report formats.
TestSuite
A test suite corresponding to a loaded test file. The suite's ID is unique in the context of this test run. It's used elsewhere in the protocol to refer to this suite without including its full representation. A suite's platform is one of the platforms that can be passed to the --platform option, or null if there is no platform (for example if the file doesn't exist at all). Its path is either absolute or relative to the root of the current package.

Enums

TestResult
The result of a test.

Extensions

TestEventPatterns on TestEvent
Adds pattern-matching-related methods to TestEvent.
TestGroupPatterns on TestGroup
Adds pattern-matching-related methods to TestGroup.
TestMetadataPatterns on TestMetadata
Adds pattern-matching-related methods to TestMetadata.
TestPatterns on Test
Adds pattern-matching-related methods to Test.
TestSuitePatterns on TestSuite
Adds pattern-matching-related methods to TestSuite.