TestEvent.allSuites constructor

const TestEvent.allSuites({
  1. required int count,
  2. required int time,
})

A single suite count event is emitted once the test runner knows the total number of suites that will be loaded over the course of the test run. Because this is determined asynchronously, its position relative to other events (except TestStartTestEvent) is not guaranteed.

Implementation

const factory TestEvent.allSuites({
  /// The total number of suites that will be loaded.
  required int count,

  /// {@macro test_event.time}
  required int time,
}) = TestAllSuitesEvent;