TestMetadata class abstract

Test metadata regarding whether the test was skipped and the reason.

Available extensions
Annotations
  • @freezed

Constructors

TestMetadata({required bool skip, required String? skipReason})
Test metadata regarding whether the test was skipped and the reason.
const
factory
TestMetadata.fromJson(Map<String, dynamic> json)
Test metadata regarding whether the test was skipped and the reason.
factory

Properties

copyWith → $TestMetadataCopyWith<TestMetadata>
Create a copy of TestMetadata with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
skip bool
Whether the test was skipped.
no setterinherited
skipReason String?
The reason the tests was skipped, or null if it wasn't skipped.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TestMetadata value)) → TResult

Available on TestMetadata, provided by the TestMetadataPatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TestMetadata value)?) → TResult?

Available on TestMetadata, provided by the TestMetadataPatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TestMetadata value)?, {required TResult orElse()}) → TResult

Available on TestMetadata, provided by the TestMetadataPatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(bool skip, String? skipReason)?, {required TResult orElse()}) → TResult

Available on TestMetadata, provided by the TestMetadataPatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TestMetadata to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(bool skip, String? skipReason)) → TResult

Available on TestMetadata, provided by the TestMetadataPatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(bool skip, String? skipReason)?) → TResult?

Available on TestMetadata, provided by the TestMetadataPatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited