TestSuite class abstract

A test suite corresponding to a loaded test file. The suite's ID is unique in the context of this test run. It's used elsewhere in the protocol to refer to this suite without including its full representation. A suite's platform is one of the platforms that can be passed to the --platform option, or null if there is no platform (for example if the file doesn't exist at all). Its path is either absolute or relative to the root of the current package.

Available extensions
Annotations
  • @freezed

Constructors

TestSuite({required int id, required String platform, required String? path})
A test suite corresponding to a loaded test file. The suite's ID is unique in the context of this test run. It's used elsewhere in the protocol to refer to this suite without including its full representation. A suite's platform is one of the platforms that can be passed to the --platform option, or null if there is no platform (for example if the file doesn't exist at all). Its path is either absolute or relative to the root of the current package.
const
factory
TestSuite.fromJson(Map<String, dynamic> json)
A test suite corresponding to a loaded test file. The suite's ID is unique in the context of this test run. It's used elsewhere in the protocol to refer to this suite without including its full representation. A suite's platform is one of the platforms that can be passed to the --platform option, or null if there is no platform (for example if the file doesn't exist at all). Its path is either absolute or relative to the root of the current package.
factory

Properties

copyWith → $TestSuiteCopyWith<TestSuite>
Create a copy of TestSuite with the given fields replaced by the non-null parameter values.
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
id int
An opaque ID for the group.
no setterinherited
path String?
The path to the suite's file, or null if that path is unknown.
no setterinherited
platform String
The platform on which the suite is running.
no setterinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

map<TResult extends Object?>(TResult $default(_TestSuite value)) → TResult

Available on TestSuite, provided by the TestSuitePatterns extension

A switch-like method, using callbacks.
mapOrNull<TResult extends Object?>(TResult? $default(_TestSuite value)?) → TResult?

Available on TestSuite, provided by the TestSuitePatterns extension

A variant of map that fallback to returning null.
maybeMap<TResult extends Object?>(TResult $default(_TestSuite value)?, {required TResult orElse()}) → TResult

Available on TestSuite, provided by the TestSuitePatterns extension

A variant of map that fallback to returning orElse.
maybeWhen<TResult extends Object?>(TResult $default(int id, String platform, String? path)?, {required TResult orElse()}) → TResult

Available on TestSuite, provided by the TestSuitePatterns extension

A variant of when that fallback to an orElse callback.
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() Map<String, dynamic>
Serializes this TestSuite to a JSON map.
inherited
toString() String
A string representation of this object.
inherited
when<TResult extends Object?>(TResult $default(int id, String platform, String? path)) → TResult

Available on TestSuite, provided by the TestSuitePatterns extension

A switch-like method, using callbacks.
whenOrNull<TResult extends Object?>(TResult? $default(int id, String platform, String? path)?) → TResult?

Available on TestSuite, provided by the TestSuitePatterns extension

A variant of when that fallback to returning null

Operators

operator ==(Object other) bool
The equality operator.
inherited