A single test case. The test's ID is unique in the context of this test run.
It's used elsewhere in the protocol to refer to this test
without including its full representation.
A group containing test cases.
The group's ID is unique in the context of this test run.
It's used elsewhere in the protocol to refer to this group
without including its full representation.
A test suite corresponding to a loaded test file.
The suite's ID is unique in the context of this test run.
It's used elsewhere in the protocol to refer to this suite
without including its full representation.
A suite's platform is one of the platforms that can be passed to the
--platform option, or null if there is no platform
(for example if the file doesn't exist at all).
Its path is either absolute or relative to the root of the current package.