TestGroup class abstract
A group containing test cases. The group's ID is unique in the context of this test run. It's used elsewhere in the protocol to refer to this group without including its full representation.
- Available extensions
- Annotations
-
- @freezed
Constructors
- TestGroup({required int id, required String name, required int suiteID, required int? parentID, required int testCount, required int? line, required int? column, required String? url, required TestMetadata metadata})
-
A group containing test cases.
The group's ID is unique in the context of this test run.
It's used elsewhere in the protocol to refer to this group
without including its full representation.
constfactory
-
TestGroup.fromJson(Map<
String, dynamic> json) -
A group containing test cases.
The group's ID is unique in the context of this test run.
It's used elsewhere in the protocol to refer to this group
without including its full representation.
factory
Properties
- column → int?
-
The (1-based) column on which the group was defined, or
null.no setterinherited -
copyWith
→ $TestGroupCopyWith<
TestGroup> -
Create a copy of TestGroup
with the given fields replaced by the non-null parameter values.
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- id → int
-
An opaque ID for the group.
no setterinherited
- line → int?
-
The (1-based) line on which the group was defined, or
null.no setterinherited - metadata → TestMetadata
-
This field is deprecated and should not be used.
no setterinherited
- name → String
-
The name of the group, including prefixes from any containing groups.
no setterinherited
- parentID → int?
-
The ID of the group's parent group, unless it's the root group.
no setterinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- suiteID → int
-
The ID of the suite containing this group.
no setterinherited
- testCount → int
-
The number of tests (recursively) within this group.
no setterinherited
- url → String?
-
The URL for the file in which the group was defined, or
null.no setterinherited
Methods
-
map<
TResult extends Object?> (TResult $default(_TestGroup value)) → TResult -
Available on TestGroup, provided by the TestGroupPatterns extension
Aswitch-like method, using callbacks. -
mapOrNull<
TResult extends Object?> (TResult? $default(_TestGroup value)?) → TResult? -
Available on TestGroup, provided by the TestGroupPatterns extension
A variant ofmapthat fallback to returningnull. -
maybeMap<
TResult extends Object?> (TResult $default(_TestGroup value)?, {required TResult orElse()}) → TResult -
Available on TestGroup, provided by the TestGroupPatterns extension
A variant ofmapthat fallback to returningorElse. -
maybeWhen<
TResult extends Object?> (TResult $default(int id, String name, int suiteID, int? parentID, int testCount, int? line, int? column, String? url, TestMetadata metadata)?, {required TResult orElse()}) → TResult -
Available on TestGroup, provided by the TestGroupPatterns extension
A variant ofwhenthat fallback to anorElsecallback. -
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toJson(
) → Map< String, dynamic> -
Serializes this TestGroup to a JSON map.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
when<
TResult extends Object?> (TResult $default(int id, String name, int suiteID, int? parentID, int testCount, int? line, int? column, String? url, TestMetadata metadata)) → TResult -
Available on TestGroup, provided by the TestGroupPatterns extension
Aswitch-like method, using callbacks. -
whenOrNull<
TResult extends Object?> (TResult? $default(int id, String name, int suiteID, int? parentID, int testCount, int? line, int? column, String? url, TestMetadata metadata)?) → TResult? -
Available on TestGroup, provided by the TestGroupPatterns extension
A variant ofwhenthat fallback to returningnull
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited